// Select all the elements in the HTML page
// and assign them to a variable

let playerTitle = document.querySelector(".player-title");
let playerCurrentTime = document.querySelector(".player-current-time");
let playerTotalTime = document.querySelector(".player-total-time");
 
let playerPlay = document.querySelector(".player-play");

let playerNext  = document.querySelector(".player-next");
let playerPrev  = document.querySelector(".player-prev");
 
let playerSeek = document.querySelector(".player-seek-slider");
 
// Specify globally used values
let playerIndex = 0;
let playerIsPlaying = false;
let updateTimer;
 
// Create the audio element for the player
let playerCurrentTrack = document.createElement('audio');
 
// Define the list of tracks that have to be played
let playerTrackList = [
	{
	name: "descend",
	path: "/audio/ended/01-descend.mp3"
	},
	{
	name: "emotive",
	path: "/audio/ended/02-emotive.mp3"
	},
	{
	name: "two",
	path: "/audio/ended/03-two.mp3"
	},
	{
	name: "41515",
	path: "/audio/ended/04-41515.mp3"
	},
	{
	name: "song for melissa",
	path: "/audio/ended/05-song-for-melissa.mp3"
	},
	{
	name: "island/heat death",
	path: "/audio/ended/06-island-heat-death.mp3"
	}
];

function loadTrack(playerIndex) {
  // Clear the previous seek timer
  clearInterval(updateTimer);
  resetValues();
 
  // Load a new track
  playerCurrentTrack.src = playerTrackList[playerIndex].path;
  playerCurrentTrack.load();
 
  // Update details of the track
  playerTitle.textContent = playerTrackList[playerIndex].name;
 
  // Set an interval of 1000 milliseconds
  // for updating the seek slider
  updateTimer = setInterval(seekUpdate, 1000);
 
  // Move to the next track if the current finishes playing
  // using the 'ended' event
  playerCurrentTrack.addEventListener("ended", nextTrack);
}

// Function to reset all values to their default
function resetValues() {
  playerCurrentTime.textContent = "00:00";
  playerTotalTime.textContent = "00:00";
  playerSeek.value = 0;
}

function playpauseTrack() {
  // Switch between playing and pausing
  // depending on the current state
  if (!playerIsPlaying) playTrack();
  else pauseTrack();
}
 
function playTrack() {
  // Play the loaded track
  playerCurrentTrack.play();
  playerIsPlaying = true;
}
 
function pauseTrack() {
  // Pause the loaded track
  playerCurrentTrack.pause();
  playerIsPlaying = false;
}
 
function nextTrack() {
  // Go back to the first track if the
  // current one is the last in the track list
  if (playerIndex < playerTrackList.length - 1)
    playerIndex += 1;
  else playerIndex = 0;
 
  // Load and play the new track
  loadTrack(playerIndex);
  playTrack();
}
 
function prevTrack() {
  // Go back to the last track if the
  // current one is the first in the track list
  if (playerIndex > 0)
    playerIndex -= 1;
  else playerIndex = playerTrackList.length - 1;
   
  // Load and play the new track
  loadTrack(playerIndex);
  playTrack();
}

function seekTo() {
  // Calculate the seek position by the
  // percentage of the seek slider
  // and get the relative duration to the track
  seekto = playerCurrentTrack.duration * (playerSeek.value / 100);
 
  // Set the current track position to the calculated seek position
  playerCurrentTrack.currentTime = seekto;
}
 
function seekUpdate() {
  let seekPosition = 0;
 
  // Check if the current track duration is a legible number
  if (!isNaN(playerCurrentTrack.duration)) {
    seekPosition = playerCurrentTrack.currentTime * (100 / playerCurrentTrack.duration);
    playerSeek.value = seekPosition;
 
    // Calculate the time left and the total duration
    let currentMinutes = Math.floor(playerCurrentTrack.currentTime / 60);
    let currentSeconds = Math.floor(playerCurrentTrack.currentTime - currentMinutes * 60);
    let durationMinutes = Math.floor(playerCurrentTrack.duration / 60);
    let durationSeconds = Math.floor(playerCurrentTrack.duration - durationMinutes * 60);
 
    // Add a zero to the single digit time values
    if (currentSeconds < 10) { currentSeconds = "0" + currentSeconds; }
    if (durationSeconds < 10) { durationSeconds = "0" + durationSeconds; }
    if (currentMinutes < 10) { currentMinutes = "0" + currentMinutes; }
    if (durationMinutes < 10) { durationMinutes = "0" + durationMinutes; }
 
    // Display the updated duration
    playerCurrentTime.textContent = currentMinutes + ":" + currentSeconds;
    playerTotalTime.textContent = durationMinutes + ":" + durationSeconds;
  }
}

loadTrack(playerIndex);